#
# spec file for package docker-buildx
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define archive_name buildx
%define binary_name buildx

Name:           docker-buildx
Version:        0.10.2
Release:        bp155.1.22
Summary:        Docker CLI plugin for extended build capabilities with BuildKit
License:        Apache-2.0
URL:            https://github.com/docker/buildx
Source:         buildx-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  docker
BuildRequires:  go >= 1.17
Requires:       docker

%description
buildx is a Docker CLI plugin for extended build capabilities with BuildKit.

Key features:
- Familiar UI from docker build
- Full BuildKit capabilities with container driver
- Multiple builder instance support
- Multi-node builds for cross-platform images
- Compose build support
- High-level build constructs (bake)
- In-container driver support (both Docker and Kubernetes)

%prep
%setup -q -n %{archive_name}-%{version}
%setup -q -n %{archive_name}-%{version} -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/docker-buildx ./cmd/buildx

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/usr/lib/docker/cli-plugins/%{name}"

%files
%doc README.md
%license LICENSE
/usr/lib/docker/
/usr/lib/docker/cli-plugins/
/usr/lib/docker/cli-plugins/%{name}

%changelog
* Tue Jan 31 2023 kastl@b1-systems.de
- Update to version 0.10.2:
  * build: better message output for git provenance
  * build: silently fail if git remote not found
  * build: fix multi-node merge to read descriptor from result
  * bake: SOURCE_DATE_EPOCH: fix `panic: assignment to entry in nil map`
  * build: fix preferred platform not taken account
* Fri Jan 27 2023 kastl@b1-systems.de
- Update to version 0.10.1:
  * vendor: update buildkit to v0.11.2
  * build: set remote origin url
  * build: create error group per opt
  * build: reorder error group funcs
  * build: use copy for BuildWithResultHandler loop vars
  * imagetools: silence intoto warnings
  * rm: do not check for context builders when removing inactive
  * build: mark capabilities request as internal
  * docs: fix broken link in buildx_bake CLI reference
  * ci: fix typo in docs-release workflow
  * fix the directory of the buildx binary
  * inspect: lazily load attestation data
  * inspect: move attestation loading to struct methods
  * build: error when using docker exporter and attestations
  * build: avoid compatability error when attestations disabled
  * ci: update buildkit release version in build pipeline
  * ci: update buildx release version in build pipeline
  * vendor: github.com/moby/buildkit v0.11.1
  * docs: add reference for new attest family of flags
* Tue Jan 10 2023 kastl@b1-systems.de
- Update to version 0.10.0:
  * docs: update with new inspect output
  * inspect: change additional spdxs to not have duplicates
  * inspect: provide access to multiple spdx documents
  * inspect: parse sbom and provenance into json structs
  * inspect: break after first matching attestation
  * github: update CI to buildkit v0.11
  * go.mod: update cli-docs-tool v0.5.1 and re-generate docs
  * docs: update anchor links
  * imagetools inspect: handle provenance and sbom
  * imagetools inspect: missing annotations key
  * vendor: update buildkit to v0.11.0-rc4
  * docs: update oci layout with tag resolution
  * build: refactor reference parsing for image layouts
  * e2e: use native k3s installation script
  * Propagate SOURCE_DATE_EPOCH from the client env
  * disable buildx experimental in pipeline
  * readme: fix status badge
  * build: check error from toSolveOpt before adding FrontendAttrs
  * git: do not show warnings if project does not use git
  * github: update buildkit image to v0.11-rc3
  * build: warn if git operation fails
  * build: lookup the right git binary on WSL
  * build: forward all build opts everywhere
  * ci: generate provenance and sbom for bin image
  * ci: generate provenance and sbom for release binaries
  * buildflags: warn on duplicate attest field
  * ci: update to ubuntu 22.04
  * ci: fix deprecated set-output syntax
  * ci: do not publish docs on prerelease
  * builder: check endpoint from store when loading factory
  * build: fix env vars check for vcs details
  * bake: support null label value
  * bake: support null arg value
  * bake: add tests for block interpolation
  * bake: support block-based interpolation
  * bake: add cty tags to hcl structures
  * build: set provenance vcs details
  * e2e: load to docker store
  * vendor: update buildkit to 862b22d7
  * vendor: update buildkit to 93b40706a007
  * store: set nodegroup last activity
  * store: use constants for directory names
  * vendor: github.com/moby/buildkit v0.11.0-rc1.0.20221207183946-5993b526de65
  * build: don't set add-hosts option if empty
  * bake: add attests field
  * build: add attests flag and sbom/provenance shorthands
  * build: add attestations to build options
  * build: pass attestation attributes to build request
  * chore: sort buildOptions alphabetically
  * store: skip DockerContext field from being saved
  * builder: fix default docker context behavior
  * builder: enhance driver factory logic when loading drivers
  * mutualize builder logic
  * dockerutil pkg to manage docker api client and context
  * kubernetes: fix context load test
  * vendor: update buildkit to master@9624ab4
  * hcl: SrcRange not checked when solving JSON func calls
  * build: skip "host-gateway" validation with moby driver
  * docs: moved manual pages to docs repo, added link
  * bake: fix panic for unsupported hcl variable type
  * imagetools: set default repo ref on creation if nil
  * go.mod: golang_protobuf_extensions v1.0.4 - prevent incompat versions
  * hack: mutualize build opts in Makefile and Dockerfile
  * hack: improve hash-files script
  * build(deps): Bump peter-evans/create-pull-request from 4.2.2 to 4.2.3
  * ci: update softprops/action-gh-release to v0.1.15
  * build(deps): Bump peter-evans/create-pull-request from 4.2.0 to 4.2.2
  * docs: add tar flag to oci+docker exporters
  * build: support tar flag for oci+docker exporters
  * vendor: update buildkit to master@ae9d0f5
  * docs: clarify support for various sets of shared options
  * Correction in Synopsis.
  * kubernetes: move context config logic to its own pkg
  * docs: add cache persistence notes for docker-container driver
  * go.mod: golang.org/x/crypto v0.1.0
  * Address feedback
  * Synchronise access to the map when printing.
  * docs: use consistent "Type" header across parameter tables
  * docs: add env parameter to docker-container driver
  * Correct documentation on gha scopes
  * use double spaces with json marshal indent
  * go.mod: github.com/spf13/cobra v1.6.1
  * docs: refactored file and directory structure
  * docs: update git ref to docs repo
  * docs: change cache storage links to exporter to docs site
  * ci(docs-upstream): switch to reusable workflow
  * update github.com/compose-spec/compose-go to v1.6.0
  * docs: add exporter docs
  * driver: don't create tracer delegate opt if tracer is nil
  * progress: explicitly fail if tty requested but not available
  * hack: lint scripts
  * hack: use single output dir
  * docker-container: move userns detection into driver
  * chore: tidy up duplicate dockertypes import
  * lint: add nolintlint and fix violations
  * lint: remove structcheck
  * build(deps): Bump peter-evans/create-pull-request from 4.1.4 to 4.2.0
  * docs: add user sign for console blocks
  * build(deps): Bump peter-evans/create-pull-request from 4.1.3 to 4.1.4
  * docs: fix typo in cache docs
  * go.mod: matttproud/golang_protobuf_extensions v1.0.2 (use tag)
  * docs: fix cache command examples
  * docs: replaced broken relative links
  * changed from relative to absolute links
  * moved context arg to last
  * review comments, align style with driver docs
  * address review comments
  * fix incorrect heading text
  * improve wording on default buildkit image
  * updated prose and structure for driver docs
  * bake: do not fail printing definition if instance unavailable
  * Fix assignment to nil map
  * Support empty env var when it can't be unset
  * added tables for cache parameters
  * build(deps): Bump peter-evans/create-pull-request from 4.1.2 to 4.1.3
  * remove unrelated comment after upgrade
  * ci: don't trigger build and e2e workflows on docs-only pull requests
  * docs: final cache storage fixups
  * docs: additions from editorial review
  * docs: add cache storage backend docs
  * build(deps): Bump peter-evans/create-pull-request from 4.0.4 to 4.1.2
  * invoke: load defaults from image config
  * docs: update links to new docs
  * docs: update links in driver guide
  * bake: recursively resolve groups
  * kubernetes: rootless: support Google Container-Optimized OS
  * Add git provenance labels
  * return di.Err when it's not nil
  * progress: add prefix to vertex progress group
  * store: move regex to where it's used
  * s3 cache client-side support
  * vendor: bump compose-go to v1.5.0
  * docs: missing syntax directive
  * docs: make sure all named context examples use 1.4
  * Dockerfile: update golangci-lint to 1.48.0 (go 1.19 support)
  * Dockerfile: update to go 1.19
  * docker api: use helper to parse context docker endpoint metadata
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.9.1:
  * buildx: prevent duplicate "failed to find driver" message
  * docs: update buildx inspect reference with buildkit version
  * inspect: add buildkit version information to command output
  * bake: test compose file validation
  * bake: test for unknown extensions
  * bake(compose): fix unskipped services without build context
  * docs: add experimental options to build command reference
  * build: ensure consistent help messages for experimental cli help
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.9.0:
  * vendor: update buildkit to 55ba9d14
  * create: improve interface when attempting to create docker driver
  * commands: use buildx env for experimental opt-in
  * build: update outline fallback image
  * bake: load .env file from working dir for compose files
  * test: misplaced expected value in assert
  * enable other exporters if docker driver uses containerd
  * add formatting support to print function
  * build: add fallback to outline requests if not supported by frontend
  * build: add experimental support for print flag
  * detect moby worker supports multiplatform feature through containerd snapshotter
  * build: fix issues with leaving invoke containers running
  * docs: add correct definition of prune --all flag
  * invoke: add messages
  * prune: cleanup variable names for clarity
  * buildx: warn on editing nodes
  * bake: contexts support with x-bake
  * vendor: v20.10.3-0.20220803220330-418ca3b4d46f (v22.06.0-dev)
  * ci: enhanced build workflow
  * docs: fix dead link to color output controls guide
  * ci: upstream docs conformance validation
  * prune: fix filter until option
  * update github.com/compose-spec/compose-go to v1.4.0
  * buildx: forbid mismatched drivers
  * kubernetes: error about unused endpoint argument
  * add jedevc to maintainers
  * ci: open pr on docs repo only on release
  * kubernetes: enable azure auth
  * update github.com/compose-spec/compose-go to v1.3.0
  * chore: fix readme
  * bake(compose): allow dot in target name
  * docs: add minimal docker driver docs
  * check context builder endpoint
  * imagetools: support cross-repo mounting
  * imagetools: give imagetools create a progress bar
  * imagetools: copy manifests between repositories
  * imagetools: refactor combining repository logic
  * docs: fix link to docs website
  * docs: fix link
  * docs: add further reading section for drivers
  * docs: add basic docker-container driver guide
  * docs: create dedicated drivers section
  * docs(bake): set experimental note
  * docs(bake): fix target fields and show type
  * buildx: rollback configuration if create fails
  * docs: update cli-docs-tool to v0.5.0
  * docs: remove frontmatter section
  * docs(guide): color output controls
  * docs: replace links with ones from docs.docker.com
  * ci: release workflow to open a PR on docs repo with latest changes
  * vendor: update docker/cli to f1615fa
  * Update buildkit w/ customizable output colors, etc.
  * Update xx to 1.1.2
  * docs(guides): fix links
  * add support for oci-layout build-context
  * bake: add timestamp function
  * docs: add new kubernetes build driver docs
  * fix: correct determnistic word
  * buildx: log errors in initializing builders
  * docs: fixup remote builder typos
  * bake: add tests for missing attributes in userfuncs
  * bake: forbid empty result and params in userfuncs
  * kubernetes: add error when no pods available
  * vendor: bump buildkit to master
  * bake: dedup compose main and extension fields values
  * bake: merge cache-from field from compose and x-bake
  * bake: support compose build cache_to
  * bake: fix compose consistency check
  * chore: remove yamllint
  * Add `--invoke` option to launch a container from the build result
  * bake: better handling of compose extension interface
  * bake: support compose build tags
  * bake: support compose secrets env
  * ci: add concurrency check
  * docs: rework bake compose file definition
  * update github.com/compose-spec/compose-go to v1.2.7
  * docs: rework bake "Configuring builds" page
  * docs: bake specification intro
  * docs: guide page to configure bake builds
  * docs: changes to bake file definition guide
  * docs: bake guides and refactor reference
  * build: enhance warning message when no output specified
  * build(deps): bump crazy-max/ghaction-github-runtime from 1.0.0 to 2
  * docs: add connhelpers info to remote-builder guide
  * remote: add additional connhelpers to buildx
  * vendor: update moby/buildkit
  * ls: move builder/node status error msg below table
  * imagetools: handle manifest with nil platform
  * Update golint to revive
  * cli: uppercase level to match logrus one
  * rm: display name of removed builder
  * rm: disallow removing context builders
  * create: warn if instance name already exists as context builder
  * docs: fix typo in docker-container remote driver instructions
  * build: allow external Dockerfile on remote context
  * ls: dedup instances from store and context
  * Clarify inspect documentation
  * create: load default buildkit config if none specified
  * ci: pin external/untrusted github actions
  * ci: bump official actions to latest major
  * ci: remove godev workflow
  * ci: bump docker actions to latest major
  * build(deps): bump codecov/codecov-action from 2 to 3
  * Add remote driver guide
  * docs: update ls output example
  * vendor: vendor with -compat=1.17
  * ls: adds fallback if buildkit version info unimplemented
  * remote: use --bootstrap to wait for remote to become active
  * ls: display buildkit version of the nodes
  * vendor: update buildkit to c78f696
  * chore: dependabot to keep gha up to date
  * dockerfile: use gobase for test stage
  * ci: enable cache
  * ci: add check remote buildkitd step in e2e tests
  * release: fix checksum file
  * docs: fix guides for docs.docker.com
  * Add remote driver documentation
  * root: ignore SSH CloseRead warning
  * Complete remote driver
  * feat: env driver
  * ci: enhance e2e workflow
  * hclparser: strip out blocks for json files
  * hack: update linters
  * Dockerfile: update to go 1.18
  * cli: fix standalone command behavior
  * Fix tolerations not parsing its options correctly, add tests
  * bake: support compose build secrets
  * update github.com/compose-spec/compose-go to v1.2.4
  * imagetools: respect --builder flag
  * inspect: fix printing of driver options
  * Only set default rootless image if it is not already customized
  * Dockerfile: update to tonistiigi/xx:1.1.0
  * Dockerfile: update DOCKERD_VERSION to v20.10.14
  * kubernetes: replace deprecated seccomp annotations with securityContext
  * bake: merge vars from multiple JSON files
  * bake: merge targets from multiple JSON files
  * Add support for defining kubernetes tolerations
  * vendor: update buildkit to 3e38a2d
  * compose: add test for port mapping
  * update github.com/compose-spec/compose-go to v1.2.1
  * bake: fix skipped group when already visited by another one
  * vendor: github.com/docker/distribution v2.8.1
  * feat: printing driver options
  * vendor: update fsutil to 9ed61262
  * dockerfile: update frontend to 1.4
  * chore: use no-cache-filter for outdated stage
  * imagetools inspect: use buildinfo helper
  * golangci-lint: prevent io/ioutil from being used
  * Remove uses of deprecated io/ioutil
* Mon Apr  4 2022 kastl@b1-systems.de
- Update to version 0.8.2:
  * vendor: update buildkit to 10e6f94b
  * compose: add test for port mapping
  * update github.com/compose-spec/compose-go to v1.2.1
  * bake: fix skipped group when already visited by another one
* Mon Mar 21 2022 kastl@b1-systems.de
- Update to version 0.8.1:
  * bake: allow dot in target names for compose
  * vendor: update fsutil to 9ed61262
* Thu Mar 10 2022 kastl@b1-systems.de
- Update to version 0.8.0:
  * vendor: update buildkit
  * build: set remote digest when pushed with docker driver
  * bake: restore consistent output for metadata
  * imagetools inspect: missing manifest digest for manifest-list (json)
  * imagetools inspect: deterministic platform order
  * build: return imageID when loading without docker driver
  * build: fix multi-node builds with mixed platforms
  * build: remove target context if platform specific used
  * progress: avoid double logs when multiple targets build same step
  * vendor: update docker/cli to 8667ccd
  * docs: small fixes
  * vendor: update buildkit to 0692ad79
  * imagetools inspect: multi-platform support
  * imagetools inspect: add --format flag
  * docs: update cli-docs-tool to v0.4.0
  * bake: add path validation for remote bake invocations
  * bake: make named contexts relative to remote bake input
  * vendor: update buildkit to b124b0c3
  * bake: use better error in named contexts not supported
  * Fix typo in readme
  * build: fix deadlock on handling deps errors
  * set build-args from docker proxy configuration
  * build: send buildinfo dependencies
  * docs: metadata-file usage
  * docs: built-in build args
  * docs: user guides
  * docs: ssh usage example
  * docs: lint
  * vendor: update buildkit to 1e6032c
  * build(deps): bump github.com/docker/distribution
  * e2e: add bake build and display metadata json
  * build: enhance metadata json output
  * docs: built-in build args
  * forbid setting no-cache and no-cache-filter together
  * bake: add no-cache-filter
  * build: add no-cache-filter
  * docs: secret usage examples
  * vendor: update buildkit to 2f99651
  * Separate io.Writer from console.File for NewPrinter
  * cli: add --all-inactive and --force flags for rm command
  * docs: add examples for bake named contexts
  * bake: connect results between build targets
  * util: add waitmap for target synchronization
  * bake: add named contexts keys
  * bake: restrict target name
  * root: simple output format on logrus for parity with cli
  * root: filter out useless commandConn.CloseWrite warning message
  * bake: keep target inheritance
  * Update install instructions
  * bump github.com/zclconf/go-cty from 1.7.1 to 1.10.0
  * chore: invalidate cache for outdated run stage
  * ci: build with stable buildkit image
  * build: inline buildinfo attrs
  * docs: add docs for -build-context
  * commands: provide more helpful error when —build-context is not supported
  * commands: rename context flag to build-context
  * compose: resolve build args from service environment
  * compose: test env_file
  * update github.com/compose-spec/compose-go to v1.0.8
  * build: add support for named contexts
  * root: filter out useless debug logs from vendored packages
  * commands: build summary of warnings on build
  * vendor: update buildkit to 539be170
  * docker-container: set UsernsMode only when needed
  * bake: fix group resolution
  * bake: fix groups print
  * bake: ignore NetworkMode field for json and hcl
  * Remove support for network override in bake
  * imagetools resolver: fix deprecated client opt
  * imagetools resolver: discard containerd logger output
  * Remove NetworkMode support for HCL targets
  * disk usage: last accessed not displayed
  * add note about variable syntax in json
  * bake: build definition file via stdin
  * Add NetworkMode to bake target
  * docs: fix git protocol
  * bake: fix print output
  * commands: clean up unnecessary code
  * Add an option to buildx rm to keep the buildkitd daemon running
  * cli: fix flags usage
  * dockerfile: update xx to 1.0.0
* Fri Mar  4 2022 Johannes Kastl <kastl@b1-systems.de>
- new package docker-buildx: Docker CLI plugin for extended build capabilities with BuildKit
